@@ -10,6 +10,7 @@ import requests
 from gradio.utils import (
     colab_check,
     error_analytics,
+    format_ner_list,
     get_local_ip_address,
     ipython_check,
     json,
@@ -116,5 +117,28 @@ class TestIPAddress(unittest.TestCase):
         self.assertEqual(ip, "No internet connection")
 
 
+class TestFormatNERList(unittest.TestCase):
+    def test_format_ner_list_standard(self):
+        string = "Wolfgang lives in Berlin"
+        groups = [
+            {"entity_group": "PER", "start": 0, "end": 8},
+            {"entity_group": "LOC", "start": 18, "end": 24},
+        ]
+        result = [
+            ("", None),
+            ("Wolfgang", "PER"),
+            (" lives in ", None),
+            ("Berlin", "LOC"),
+            ("", None),
+        ]
+        self.assertEqual(format_ner_list(string, groups), result)
+
+    def test_format_ner_list_empty(self):
+        string = "I live in a city"
+        groups = []
+        result = [("I live in a city", None)]
+        self.assertEqual(format_ner_list(string, groups), result)
+
+
 if __name__ == "__main__":
     unittest.main()
